@@ -1,4 +1,4 @@
-#import <swarmobject.h>
+#import <objectbase.h>
 #import <space.h>
 #import <activity.h>
 #import <collections.h>
