@@ -299,11 +299,50 @@
 - _drawRasters_
 {
   if (fireRaster)
-    [fireRaster drawSelf];
+    {
+
+#ifdef FIRE_SCREENSHOT
+      MAKE_RASTER_SCREENSHOT(fireRaster);
+#endif
+      [fireRaster drawSelf];
+    }
   if (forestRaster)
-    [forestRaster drawSelf];
+    {
+#ifdef FOREST_SCREENSHOT
+      MAKE_RASTER_SCREENSHOT(forestRaster);
+#endif
+      [forestRaster drawSelf];
+    }
   if (youngForestRaster)
-    [youngForestRaster drawSelf];
+    {      
+#ifdef YOUNG_FOREST_SCREENSHOT
+      MAKE_RASTER_SCREENSHOT(youngForestRaster);
+#endif
+      [youngForestRaster drawSelf];
+    }
+  return self;
+} 
+
+- _drawGraphs_
+{
+  if (showPopulationGraph)
+    {
+#ifdef POPGRAPH_SCREENSHOT      
+      MAKE_EZGRAPH_SCREENSHOT(popGraph);
+#endif
+      [popGraph step];
+    }
+#ifdef SPECIESGRAPH_SCREENSHOT        
+  MAKE_EZGRAPH_SCREENSHOT(speciesGraph);
+#endif
+  [speciesGraph step];
+
+  [speciesEntropy update];
+#ifdef ENTROPYGRAPH_SCREENSHOT        
+  MAKE_EZGRAPH_SCREENSHOT(entropyGraph);
+#endif
+  [entropyGraph step];
+
   return self;
 }
 
@@ -332,13 +371,16 @@
                       message: M(drawSelf)];
 
   [displayActions createActionTo: self message: M(_drawRasters_)];
-  if (showPopulationGraph)
-    [displayActions createActionTo: popGraph message: M(step)];
+
+  [displayActions createActionTo: self message: M(_drawGraphs_)];
+
+  //  if (showPopulationGraph)
+  //      [displayActions createActionTo: popGraph message: M(step)];
   
-  [displayActions createActionTo: speciesGraph message: M(step)];
+  //    [displayActions createActionTo: speciesGraph message: M(step)];
   
-  [displayActions createActionTo: speciesEntropy message: M(update)];
-  [displayActions createActionTo: entropyGraph message: M(step)];
+  //    [displayActions createActionTo: speciesEntropy message: M(update)];
+  //    [displayActions createActionTo: entropyGraph message: M(step)];
 
   [displayActions createActionTo: probeDisplayManager message: M(update)];
   [displayActions createActionTo: actionCache message: M(doTkEvents)];
